SystemOrganization addCategory: #SqSaveMySqlDriver!

SqsDatabaseConnection subclass: #SqsMySqlConnection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SqSaveMySqlDriver'!

!SqsMySqlConnection methodsFor: 'accessing' stamp: 'tkow 3/3/2009 13:31'!
close
	self isAlive ifTrue: [
		connection close	
	]
	! !

!SqsMySqlConnection methodsFor: 'connection-control' stamp: 'tkow 3/19/2009 14:22'!
executeQuery: anSqlQuery
	| subQueries |
	subQueries := anSqlQuery isString ifTrue: [Array with: anSqlQuery] ifFalse: [anSqlQuery].
	subQueries allButLastDo: [ :query |
		(connection createStatement) executeQuery: (query)		
	].
	^ (connection createStatement) executeQuery: (subQueries last)
	
	
	! !

!SqsMySqlConnection methodsFor: 'accessing' stamp: 'tkow 3/5/2009 21:17'!
init
	connection initialize2.
	(self executeQuery: 'SET autocommit = 0').
! !

!SqsMySqlConnection methodsFor: 'testing' stamp: 'tkow 10/27/2008 17:14'!
isAlive
	^(connection socket notNil) and: [connection socket isConnected]! !

!SqsMySqlConnection methodsFor: 'connection-control' stamp: 'tkow 10/29/2008 14:04'!
nextRowFromResult: result
	^ result next ifTrue: [
		result currentRowAsDictionary 
	] ifFalse: [
		nil
	]! !

!SqsMySqlConnection methodsFor: 'converting' stamp: 'tkow 12/13/2008 12:21'!
rowDictionariesForResultSet: result 
	| resultDicts |
	resultDicts := OrderedCollection new.
	"damn...I really need a proper mysql driver, this one returns JdmResult or JdmResultSets"
	(result class includesBehavior: JdmResult) ifTrue: [
		^ resultDicts	
	].
	
	"store all data rows in our own structure - this way we can issue new commands upon object creation"
	[ result next ] whileTrue: [ 
		resultDicts add: result currentRowAsDictionary 
	].
	^resultDicts! !

SqsConnectionSpecification subclass: #SqsMySQLConnectionSpecification
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SqSaveMySqlDriver'!

!SqsMySQLConnectionSpecification class methodsFor: 'as yet unclassified' stamp: 'tkow 3/6/2009 14:39'!
user: aUsername password: aPassword database: aDatabaseName 
	"just for the lazy people like me - creates a mysql connection..."
	^ self new
		username: aUsername;
		password: aPassword;
		port: 3306;
		database: aDatabaseName;
		driverClass: #SqsMysqlAdapter;
		hostname: 'localhost'! !

!SqsMySQLConnectionSpecification class methodsFor: 'as yet unclassified' stamp: 'tkow 3/6/2009 14:40'!
user: aUsername password: aPassword database: aDatabaseName port: aPort
	"just for the lazy people like me - creates a mysql connection..."
	^ self new
		username: aUsername;
		password: aPassword;
		port: aPort;
		database: aDatabaseName;
		driverClass: #SqsMysqlAdapter;
		hostname: 'localhost'! !

!SqsMySQLConnectionSpecification class methodsFor: 'as yet unclassified' stamp: 'tkow 3/6/2009 14:41'!
user: aUsername password: aPassword database: aDatabaseName port: aPort host: aHostName
	"just for the lazy people like me - creates a mysql connection..."
	^ self new
		username: aUsername;
		password: aPassword;
		port: aPort;
		database: aDatabaseName;
		driverClass: #SqsMysqlAdapter;
		hostname: aHostName! !

SqsDatabaseAdapter subclass: #SqsMysqlAdapter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SqSaveMySqlDriver'!

!SqsMysqlAdapter class methodsFor: 'standard-values' stamp: 'tkow 3/6/2009 14:06'!
maxFieldLength
	^ 60! !

!SqsMysqlAdapter class methodsFor: 'instance creation' stamp: 'tkow 4/19/2009 22:37'!
newConnectionFor: anSqsConSpec 
	| spec connection |
	Socket initializeNetwork.
	spec := (Smalltalk at: #JdmConnectionSpec) new initialize
		user: anSqsConSpec username;
		password: anSqsConSpec password;
		host: (NetNameResolver addressForName: anSqsConSpec hostname);
		database: anSqsConSpec database;
		port: anSqsConSpec port.
	connection := (Smalltalk at: #JdmConnection) on: spec.
	^ SqsMySqlConnection withConnection: connection! !

!SqsMysqlAdapter methodsFor: 'data-preparation' stamp: 'tkow 12/11/2008 17:42'!
columnName: columnName aliasedWith: aliasName
	^ (super columnName: columnName aliasedWith: aliasName) asSqlValueString! !

!SqsMysqlAdapter methodsFor: 'database operations' stamp: 'tkow 3/5/2009 17:39'!
getConnectionIfNecessary
	super getConnectionIfNecessary.
! !

!SqsMysqlAdapter methodsFor: 'database operations' stamp: 'tkow 3/3/2009 14:08'!
lastOidOf: aTable fromResults: results
	 | oid |
	"MySQL will only retrun the last ID. Postgres needs the table part"  
	results collect: [:table |
		oid := (table at: self oidFieldAlias) asString asInteger. 	
	].
	^oid.
	! !

!SqsMysqlAdapter methodsFor: 'sql statements' stamp: 'tkow 3/3/2009 14:11'!
oidFieldAlias
	^'OID'! !

!SqsMysqlAdapter methodsFor: 'database operations' stamp: 'tkow 12/11/2008 14:16'!
queryForAllUserTables
	^ 'SHOW TABLES'! !

!SqsMysqlAdapter methodsFor: 'sql statements' stamp: 'tkow 3/3/2009 14:10'!
queryForLastOidOfTable: aTable 
	^ 'SELECT LAST_INSERT_ID() AS ', self oidFieldAlias! !

!SqsMysqlAdapter methodsFor: 'sql statements' stamp: 'tkow 9/19/2008 13:47'!
queryToCreateJoinTable: tableDescription
	^ (super queryToCreateJoinTable: tableDescription) , ' ENGINE=INNODB'.! !

!SqsMysqlAdapter methodsFor: 'sql statements' stamp: 'tkow 10/7/2008 16:25'!
queryToCreateTable: anSqSTable
	^ (super queryToCreateTable: anSqSTable) , ' ENGINE=INNODB'.! !
